@@ -14,6 +14,9 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_pSession = new Spotify::Session(this); //create new Spotify session instance
 
+    m_pTimeoutTimer  = new QTimer(this); //timeout timer instance
+    connect(m_pTimeoutTimer,SIGNAL(timeout()),SLOT(OnPlaylistLoadingTimeout()));
+
     m_pAppSettings = new QSettings("qspot","qspot", this);
 
     m_pLoginDlg = new LoginDialog(m_pSession,m_pAppSettings,this); //allocate login dialog instance
@@ -31,7 +34,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_AboutDlg.setIconPixmap(appIconMap);
     m_AboutDlg.setWindowTitle(tr("About QSpot")),
-    m_AboutDlg.setText(tr("QSpot version 0.0.5-1\n\nAn open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n(C) 2010 Andreas Enbacka and the QSpot Team.\n\n"
+    m_AboutDlg.setText(tr("QSpot version 0.0.5-2\n\nAn open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n(C) 2010 Andreas Enbacka and the QSpot Team.\n\n"
                           "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout."));
 
     //init the playlist listview instance
@@ -112,6 +115,8 @@ MainWindow::MainWindow(QWidget *parent)
     m_pQueueView = new QueueView(m_pSession,this);
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32,qint32)),SLOT(OnPlayQueuePosUpdated(qint32,qint32)));
 
+    m_AudioInit = false;
+
     emit showLogin(); //emit signal requesting to show login dialog
 }
 
@@ -126,12 +131,10 @@ void MainWindow::OnSettingsSaved()
 
     if(m_pAppSettings->value("QSpot/preBufferingActive",PRE_BUFFERING_DEFAULT).toInt())
     {
-        qDebug() << "1";
         m_pSession->setPreBufferingActive(true);
     }
     else
     {
-        qDebug() << "0";
         m_pSession->setPreBufferingActive(false);
     }
 }
@@ -178,7 +181,12 @@ void MainWindow::OnActiveQueueViewChanged(bool active, bool shuffleActive)
         if(m_PlayQueue.size()>0)
         {
             m_pQueueView->setNowPlaying(m_PlayQueue,m_currQueuePos,m_playing,m_currPlaybackPos,m_currBuffPos,false,-1); //set queue (now playing) instance info
-            m_pQueueView->setActive(true,shuffleActive);
+            m_pQueueView->setUpdateBufferPos(m_pTrackView->getQueueViewUpdateBufPos());
+            if(shuffleActive)
+                m_pQueueView->setActive(true,shuffleActive);
+            else
+                m_pQueueView->setActive(true,m_pQueueView->getShuffleActive());
+
         }
     }
 }
@@ -211,6 +219,21 @@ void MainWindow::OnPlaybackPositionUpdated(qint64 pos)
         }
 }
 
+void MainWindow::keyPressEvent(QKeyEvent *evt)
+{
+    //overriden keyPress event handler
+
+    if(evt->key()==Qt::Key_Right)
+    {
+        evt->accept();
+        OnNowPlaying(); //display Now Playing window
+    }
+    else
+    {
+        QMainWindow::keyPressEvent(evt);
+    }
+}
+
 void MainWindow::OnNowPlaying()
 {
     //show the current playqueue view (now playing)
@@ -292,13 +315,32 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
     	m_pLoginDlg->setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
     	setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display main window progress indicator
     	m_pLoginDlg->hide();
-		m_SearchInput.setFocus(); //set default focus to search field
+        m_SearchInput.setFocus(); //set default focus to search field
+        m_pTimeoutTimer->start(PLAYLIST_LOADING_TIMEOUT*1000); //set timeout value
     	m_pSession->getPlaylistContainer();
     	QMaemo5InformationBox::information(this,tr("Loading playlists")); //display loading notification
     }
 }
 
+void MainWindow::OnPlaylistLoadingTimeout()
+{
+    //Timeout has occured during playlist loading, request to interrupt the loading process
 
+    m_pTimeoutTimer->stop();
+
+    if(m_pSession->playlistLoadingInProgress())
+    {
+        m_pSession->stopPlaylistLoading(); //interrupt playlist loading
+
+        QMaemo5InformationBox::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
+
+        if(!m_AudioInit)
+        {
+            m_pSession->initAudio(); //init audio interface
+            m_AudioInit = true;
+        }
+    }
+}
 
 void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
 {
@@ -306,6 +348,8 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
 
    QPixmap iconMap;
 
+   m_pTimeoutTimer->stop(); //stop timeout timer
+
    iconMap.load("/usr/share/images/icon-type-list.png"); //load playlist type icon from file
 
    QIcon listTypeIcon(iconMap);
@@ -326,8 +370,15 @@ void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
    }
 
    m_SearchInput.setDisabled(false);
+   m_SearchInput.setFocus(); //set initial (default) focus to the Search input field
    m_SearchBtn.setDisabled(false);
 
+   if(!m_AudioInit)
+   {
+       m_pSession->initAudio(); //init audio interface
+       m_AudioInit = true;
+   }
+
    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
 }
 
@@ -411,8 +462,6 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
             {//some track / tracks returned by search
                 if(m_pTrackView)
                 {
-                    m_SearchInput.setText(""); //clear search field
-                    m_SearchInput.setCursorPosition(0);
                     m_pTrackView->setSearchResults(search);
                     m_pTrackView->show();
                 }
@@ -424,6 +473,9 @@ void MainWindow::OnSearchComplete(Spotify::Search* search)
         }
     }
 
+    m_SearchInput.setText(""); //clear search field
+    m_SearchInput.setCursorPosition(0);
+    m_SearchInput.setFocus(); //set focus to search field
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
 }
 
