@@ -35,6 +35,12 @@ namespace Spotify
 
             void init(); //init the current Spotify session
 
+            void initAudio(); //init the audio / playback thread
+
+            bool playlistLoadingInProgress(); //returns true in case playlist loading (getPlaylists) is currently in progress
+
+            void stopPlaylistLoading(); //request to stop the playlist loading (getPlaylists).
+
             void setMinBufferSize(qint32 secs); //set the size of the internal FIFO queue used to hold audio data
 
             void setPreBufferingActive(bool active); //set whether track pre-buffering is active (i.e., buffer next track data in advance)
@@ -70,10 +76,16 @@ namespace Spotify
 
             bool m_ProcessEvents;
 
+            bool m_bPlaylistsLoading; //TRUE in case playlist loading is in progress
+
+            bool m_bStopPlaylistLoading; //TRUE in case playlist loading should be stopped (interrupted)
+
             bool m_DisableNotifyThread;
 
             bool m_preBufActive; //true if track pre-buffering is enabled
 
+            QTimer *m_pProcEvtTimer;
+
 
 
             /**
