@@ -96,6 +96,14 @@ namespace Spotify
              */
             void sortByAlbums(bool ascending);
 
+            /**
+             * Sort tracks by popularity (descending)
+             */
+            void sortByPopularity();
+
+            /**
+             * Restore original track collection order
+             */
             void restoreOrignalCollection();
 
 
